@TestOn('browser')

import 'package:test/test.dart';
import 'package:nette_neon/nette_neon.dart';

void main() {
  test('empty list', () {
    expect(Neon.decode("a: []\n"), {'a': {}});
  });

  test('empty value', () {
    expect(Neon.decode("a: \n" + "b: 1\n"), {'a': null, 'b': 1});
  });

  test('1', () {
    expect(Neon.decode("\n" + "a: {1, 2, }\n" + "b: 1"), {
      'a': {0: 1, 1: 2},
      'b': 1
    });
  });

  test('2', () {
    expect(Neon.decode(" a: 1\n" + " b: 2"), {'a': 1, 'b': 2});
  });

  test('3', () {
    expect(Neon.decode("\n" + "a: x\n" + "- x"), {'a': "x", 0: "x"});
  });

  test('4', () {
    expect(Neon.decode("\n" + "- x\n" + "a: x"), {0: "x", 'a': "x"});
  });

  test('5', () {
    expect(Neon.decode("\n" + "a:\n" + "- 1\n" + "-\n" + " - 2\n" + "b:\n" + "- 3\n" + "c: null\n" + "- 4"), {
      'a': {
        0: 1,
        1: {0: 2}
      },
      'b': {0: 3},
      'c': null,
      0: 4
    });
  });

  test('5', () {
    expect(Neon.decode("\n" + "x:\n" + "	- x\n" + "	a: x\n"), {
      'x': {0: "x", 'a': "x"}
    });
  });

  test('6', () {
    expect(Neon.decode("x:\n" + "	y:\n" + "		-\n" + "a: x"), {
      'x': {
        'y': {0: null}
      },
      'a': "x"
    });
  });
  test('7', () {
    expect(Neon.decode("\n" + "x: {\n" + "	a: 1\n" + "b: 2\n" + "}\n"), {
      'x': {'a': 1, 'b': 2}
    });
  });

  test('8', () {
    expect(Neon.decode("\n" + "{\n" + "	one\n" + "two\n" + "}\n"), {0: "one", 1: "two"});
  });

  test('9', () {
    expect(
        Neon.decode(
            "\n" + "- x: 20\n" + "  - a: 10\n" + "    b: 10\n" + "- arr:\n" + "  - 10\n" + "  - 20\n" + "- y\n"),
        {
          0: {
            'x': 20,
            0: {'a': 10, 'b': 10}
          },
          1: {
            'arr': {0: 10, 1: 20}
          },
          2: "y"
        });
  });

  test('10', () {
    expect(Neon.decode("\n" + "root:\n" + "\t- key1:\n" + "\t  key3: 123\n" + "\t"), {
      'root': {
        0: {'key1': null, 'key3': 123}
      }
    });
  });

  test('11', () {
    expect(Neon.decode("\n" + "- x:\n" + "    a: 10\n"), {
      0: {
        'x': {'a': 10}
      }
    });
  });

  test('12', () {
    expect(Neon.decode("\n" + "x:\n" + "\t a: 10\n" + "y:\n" + " \tb: 20\n"), {
      'x': {'a': 10},
      'y': {'b': 20}
    });
  });

  test('13', () {
    expect(Neon.decode("\n" + "- {null= 42}\n" + "null : 42\n"), {
      0: {"null": 42},
      "null": 42
    });
  });

  test('empty-line-before-value: 1', () {
    expect(Neon.decode("\n" + "x:\n" + "\ty\n"), {'x': "y"});
  });

  test('empty-line-before-value: 2', () {
    expect(Neon.decode("\n" + "-\n" + "\tx:\n" + "\t y\n"), {
      0: {'x': "y"}
    });
  });

  test('empty-line-before-value: 3', () {
    expect(Neon.decode("\n" + "x:\n" + "    [1, 2, 3]\n"), {
      'x': {0: 1, 1: 2, 2: 3}
    });
  });

  test('empty-line-before-value: 4', () {
    expect(Neon.decode("\n" + "-\n" + "    a\n"), {0: "a"});
  });

  // test('output-map', () {
  // 	expect(Neon.decode("foo: bar") is Neon.Map);
  // });

  // test('output-object', () {
  // 	assert.deepEqual(Neon.decode(
  // 		"\n" +
  // 		"foo: {bar: lorem, ipsum}\n" +
  // 		"- [dolor]", Neon.OUTPUT_OBJECT
  // 	), {
  // 		foo: {bar: "lorem", 0: "ipsum"},
  // 		0: {0: "dolor"}
  // 	});
  // });

  // test('output-auto', () {
  // 	assert.deepEqual(Neon.decode(
  // 		"\n" +
  // 		"- {foo: bar}\n" +
  // 		"- [lorem, 2: ipsum]\n" +
  // 		"- dolor\n", Neon.OUTPUT_AUTO
  // 	), [{foo: "bar"}, {0: "lorem", 2: "ipsum"}, "dolor"]);
  // });

  test('empty-arrays', () {
    expect(Neon.decode("\n" + "one:\n" + "two:\n"), {'one': null, 'two': null});
  });
}
