@TestOn('browser')

import 'package:test/test.dart';
import 'package:nette_neon/nette_neon.dart';

void main() {
  test('true, false, null constants and strings', () {
    final map = Neon.encode([
      true,
      'TRUE',
      'tRuE',
      'true',
      false,
      'FALSE',
      'fAlSe',
      'false',
      null,
      'NULL',
      'nUlL',
      'null',
      'yes',
      'no',
      'on',
      'off'
    ]);

    expect(
        map,
        equals(
            '[true, "TRUE", "tRuE", "true", false, "FALSE", "fAlSe", "false", null, "NULL", "nUlL", "null", "yes", "no", "on", "off"]'));
  });

  test('numbers', () {
    expect(Neon.encode([1, 1.0, 0, 0.0, -1, -1.2, '1', '1.0', '-1']), '[1, 1, 0, 0, -1, -1.2, "1", "1.0", "-1"]');
  });

  test('symbols', () {
    expect(Neon.encode(['[', ']', '{', '}', ':', ': ', '=', '#']), '["[", "]", "{", "}", ":", ": ", "=", "#"]');
  });

  test('list', () {
    expect(Neon.encode([1, 2, 3]), '[1, 2, 3]');
  });

  // test('object', () {
  //   print(Neon.encode({1: 1, 2: 2, 3: 3}));
  //   expect(Neon.encode({1: 1, 2: 2, 3: 3}), '{"1": 1, "2": 2, "3": 3}');
  // });

  // test('list with missing key', () {
  //   var arr = [];
  //   arr[1] = 1;
  //   arr[2] = 2;
  //   arr[3] = 3;
  //   expect(Neon.encode(arr), '{1: 1, 2: 2, 3: 3}');
  // });

  // test('object and array', () {
  //   expect(
  //       Neon.encode({
  //         'foo': 1,
  //         'bar': [2, 3]
  //       }),
  //       '{foo: 1, bar: [2, 3]}');
  // });

  // test('map with list', () {
  // 	expect(Neon.encode(Neon.Map.fromArray([1, 2, 3])), '[1, 2, 3]');
  // });
  // test('map with assoc array', () {
  // 	expect(Neon.encode(Neon.Map.fromObject({1: 1, "foo": 2})), '{"1": 1, foo: 2}');
  // });
  // test('map', () {
  // 	var map = new Neon.Map;
  // 	map.set(1, 1);
  // 	map.set("foo", 2);
  // 	expect(Neon.encode(map), '{1: 1, foo: 2}');
  // });

  test('entity 1', () {
    expect(Neon.encode(Neon.decode('item(a, b)')), 'item(a, b)');
  });
  test('entity 2', () {
    expect(Neon.encode(Neon.decode('item<item>(a, b)')), 'item<item>(a, b)');
  });
  test('entity 3', () {
    expect(Neon.encode(Neon.decode('item(foo: a, bar: b)')), 'item(foo: a, bar: b)');
  });

  test('entity 4', () {
    expect(Neon.encode(Neon.decode('[]()')), '[]()');
  });
  test('entity 5', () {
    expect(Neon.encode(Neon.decode('item(a, foo: b)')), 'item(0: a, foo: b)');
  });

  // test('entity 6', () {
  // 	var entity = new Neon.Entity("ent");
  // 	entity.attributes = null;
  // 	expect(Neon.encode(entity), 'ent()');
  // });

  test('block', () {
    expect(Neon.encode(["foo", "bar"], Neon.BLOCK), "- foo\n" + "- bar\n");
  });

  // test('block 2', () {
  //   expect(Neon.encode({'x': "foo", 'y': "bar"}, Neon.BLOCK), "x: foo\n" + "y: bar\n");
  // });

  // test('block 3', () {
  //   expect(
  //       Neon.encode({
  //         'x': "foo",
  //         'y': [1, 2]
  //       }, Neon.BLOCK),
  //       "x: foo\n" + "y:\n" + "	- 1\n" + "	- 2\n");
  // });

  // test('block 5', () {
  //   expect(
  //       Neon.encode({
  //         'x': "foo",
  //         'y': [1, 2]
  //       }, Neon.BLOCK),
  //       "x: foo\n" + "y:\n" + "	- 1\n" + "	- 2\n");
  // });

  // test('block 6', () {
  //   expect(
  //       Neon.encode({
  //         'a': {
  //           'foo1': {'lorem': 1},
  //           'foo2': {'lorem': 2}
  //         }
  //       }, Neon.BLOCK),
  //       "a:\n" + "	foo1:\n" + "		lorem: 1\n" + "	foo2:\n" + "		lorem: 2\n");
  // });

  test('sentence', () {
    expect(Neon.encode("Sed tempus eu tortor sagittis commodo. Phasellus luctus pharetra lectus, at vulputate ex."),
        "\"Sed tempus eu tortor sagittis commodo. Phasellus luctus pharetra lectus, at vulputate ex.\"");
  });

  test('sentence no comma', () {
    expect(Neon.encode("Sed tempus eu tortor sagittis commodo. Phasellus luctus pharetra lectus at vulputate ex."),
        "Sed tempus eu tortor sagittis commodo. Phasellus luctus pharetra lectus at vulputate ex.");
  });
}
